'''
    This file is part of PM4Py (More Info: https://pm4py.fit.fraunhofer.de).

    PM4Py is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    PM4Py is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
'''

import warnings

warnings.warn("pm4py.objects.log.util.general will be removed in a future version")

from pm4py.util.constants import CASE_ATTRIBUTE_GLUE, CASE_ATTRIBUTE_PREFIX, PARAMETER_KEY_CASE_ATTRIBUTE_PRFIX, PARAMETER_KEY_CASE_GLUE
